<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nk="http://netkernel.org" xmlns:xrl="http://netkernel.org/xrl">
	<xsl:output method="xml" />
	
	<xsl:param name="filter" nk:class="java.lang.String"/>
	<xsl:variable name="testfound" select="//tests/module/uri=substring($filter,8)"/>

	<xsl:template match="/spaces">
		<div>
			<style>.el-dark a:hover { background: #B8B7B8;}</style>
			<xrl:include>
				 <xrl:identifier>active:controlPanelInfoBox</xrl:identifier>
				 <xrl:argument name="content">
				   <div>
             <p>
               The XUnit Test Manager allows a user to run installed unit tests.
             </p>
             <p>
               The NetKernel XUnit unit test framework is a comprehensive and extensible
               ROC testing system that provides unit test execution and result reporting
               along with user defined assertions and tests.
             </p>
				   <p>
             Installed test modules expose their test suites and are displayed in the
             test manager's main panel.
             Documentation on unit testing, assertions and test extensions are covered
             in the
				   <a href="/book/view/book:mod:test:book/doc:mod:test:guide:title">XUnit documentation</a>.
           </p>
             <p>
               In the display below, each test space
               is represented by one line.
               All of those tests may be run as a unit by
               clicking the button labeled &quot;exec&quot;.
               If the button labeled &quot;view&quot; is clicked,
               a display is presented with the full listing of the unit
               tests within a test suite.
             </p>
				   </div>
				 </xrl:argument>
			</xrl:include>
			
	<link type="text/css" href="/nkse/style/css/jquery-ui-latest.css" rel="stylesheet" />
	<link type="text/css" href="/nkse/style/css/jquery-datatables-latest.css" rel="stylesheet" />
	
	<link type="text/css" rel="stylesheet" href="/tools/ae/pub/explore.css"/>
	
    <script type="text/javascript" src="/nkse/style/js/jquery-datatables-latest.js">_</script>
    <script type="text/javascript" src="/tools/ae/pub/main.js">_</script>
	
<script type="text/javascript">
<xsl:comment>
module='<xsl:value-of select="$filter"/>';
testfound=<xsl:value-of select="$testfound"/>;

<![CDATA[
$(document).ready(function()
{	a = { 'bLengthChange': false,
			'bSort': false,
			'bJQueryUI': true,
			'sPaginationType': 'full_numbers',
			'iDisplayLength': -1,
			'oLanguage': { 'sSearch': "Filter:"} };
	$("#tablelist").dataTable(a);
	window.addEventListener("pageshow", pageShown, false);
	if(!testfound)
	{	if(module.substring(0,11)=="module:urn:")
		{	module=module.substring(11);
		}
		$("#tablelist").dataTable().fnFilter(module);
	}
	
	initLinksRaw( ".el-module", "gMenuModule");
}
);

function pageShown(evt)
{	$("#spinner").hide();
}
function runall()
{	filter=$("#tablelist_filter input").val();
	checked=$("#tablelist input:checkbox:checked");
	$("#spinner").show();
	$("#execute").removeClass("btn-primary").addClass("btn-danger");
	$("#tablebox").hide();
	if(filter.length>0 || module.length>0 || checked.length>0)
	{	if(filter.length>0 && checked.length==0)
		{	$("#tablelist input:checkbox").prop("checked", true);
		}
		runbatch();
	}
	else
	{	$("#tablelist input:checkbox").prop("checked", true);
		type=$("#radio input:radio:checked").val();
		document.location='/test/exec/'+type+'/all';
	}
}
function runbatch()
{	var v="";
	$("#tablelist input:checkbox:checked").each(function()
		{	id=$(this).val();
			v+="uri="+id+"&";
		}
	);
	type=$("#radio input:radio:checked").val();
	document.location='/test/exec/'+type+'/batch?'+v;
}
function exec(id)
{	$("#spinner").show();
	parent.location="/test/exec/html/"+id;
	
}
function reset()
{	$("#tablelist").dataTable().fnFilter("");
	$("#tablelist input:checkbox").prop("checked", false);
	
}
$(window).bind("pageshow", function(e){
	$("#execute").removeClass("btn-danger").addClass("btn-primary");
	$("#tablebox").show();
	$("#spinner").hide();
}
);
]]>
</xsl:comment>
</script>
			
			<div style="float:right">
				<img id="spinner" src="/nkse/style/img/ajax-loader.gif" style="display:none;"/>
			</div>
			 
			 <div class="container">
			<div class="row form form-group">
				<div class="col-md-2">
					<button class="btn btn-primary" type="button" id="execute" onclick="runall()"><span class="icon-play"> </span> execute</button>
				</div>
				<div class="col-md-9">
					<form id="radio">
						<label style="margin-right: 5px;">Result format:</label>
						<input name="resulttype" value="html" type="radio" checked="true">HTML</input>
						<input name="resulttype" value="xml" type="radio">XML</input>
					</form>
				</div>
				<div class="col-md-1 form form-group">
				<input class="btn btn-xs btn-warning" style="margin-top: 5px;" type="button" value="Reset" onclick="reset();"/>
				</div>
			</div>
			</div>
			<div id="tablebox">
			<table id="tablelist" width="100%">
				<thead>
						<tr>
						<th>Module</th>
						<th>Test Set</th>
						<th></th>
						<th></th>
						<th></th>
						</tr>
					</thead>
					<tbody>						
						<xsl:apply-templates select="space">
							<xsl:sort select="id" />
						</xsl:apply-templates>
					</tbody>
			</table>
			
			<input class="btn btn-warning" style="margin-top: 5px;" type="button" value="Reset" onclick="reset();"/>
			</div>
		</div>
	</xsl:template>

	<xsl:template match="space">
		<xsl:if test="tests/test">
			<xsl:if test="$filter='' or not($testfound) or tests/module/uri=substring($filter,8)">
			<xsl:for-each select="tests/test">
				<tr class="el">
					<td style="font-weight: bold;" >
						<span class="ui-icon-ae ui-icon-ae-module"> </span>
						<span class="el-dark"> <a  href="/tools/ae/spaceversionredirector?space={../../id}&amp;version={../../version}"><xsl:value-of select="../../id" /></a></span> <span style="margin-left: 0.5em;"><xsl:value-of select="../../version" /></span>
						
					</td>
				<xsl:call-template name="test"/> 
				</tr>
			</xsl:for-each>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<xsl:template name="test">
		<td>
			<div>
				<b>
					<xsl:value-of select="name" />
				</b>
			</div>
			<div class="subtitle">
				<xsl:value-of select="desc" />
			</div>
		</td>
		<td>
			<input value="{id}" type="checkbox"/>
		</td>
		<td>
			<input class="btn btn-xs btn-default" type="button" value="view" onclick="parent.location='/test/view/html/{id}'"/>
		</td>
		<td>
			<input class="btn btn-xs btn-default" type="button" value="exec" onclick="javascript:exec('{id}');"/>
		</td>
	</xsl:template>

	<xsl:template match="text()" />

</xsl:stylesheet>
